Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1802)

Unified Diff: chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h

Issue 769153007: Managed bookmarks for supervised users (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix build (Android & unit_tests) Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h
diff --git a/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h b/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h
index 83248d204191fabaca6efbdf570916081f030aa0..2ad7e78e69f91f4115608b6555220f046d6daeb3 100644
--- a/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h
+++ b/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.h
@@ -232,6 +232,9 @@ willAnimateFromState:(BookmarkBar::State)oldState
// "Managed bookmarks" button on the left side, next to the apps button.
base::scoped_nsobject<BookmarkButton> managedBookmarksButton_;
+ // "Supervised bookmarks" button on the left side, next to the apps button.
+ base::scoped_nsobject<BookmarkButton> supervisedBookmarksButton_;
+
// "Other bookmarks" button on the right side.
base::scoped_nsobject<BookmarkButton> otherBookmarksButton_;
@@ -311,8 +314,9 @@ willAnimateFromState:(BookmarkBar::State)oldState
// Update the visible state of the bookmark bar.
- (void)updateVisibility;
-// Update the visible state of the extra butons on the bookmark bar: the
-// apps shortcut and the managed bookmarks folder.
+// Update the visible state of the extra buttons on the bookmark bar: the
+// apps shortcut, the managed bookmarks folder, and the supervised bookmarks
+// folder.
- (void)updateExtraButtonsVisibility;
// Hides or shows the bookmark bar depending on the current state.

Powered by Google App Engine
This is Rietveld 408576698